--[[ Text substitutions ]]
local subsUnits = {
	"target",
	"focus",
	"mouseover",
	"pet",
}

local subsInfoFuncs = {
	UnitName,
	
	function(unit)
		local level = UnitLevel(unit)
		return level > 0 and level or level < 0 and "??"
	end,
	
	UnitClass,
	
	function(unit)
		return MACROTALK_SEXES[UnitSex(unit)]
	end,
	
	function(unit)
		local race = UnitRace(unit)
		return race or MACROTALK_UNKNOWN_RACE
	end,
}

local OrigSendChatMessage = SendChatMessage
function SendChatMessage(text, ...)
	for infoIndex = 1, #subsInfoFuncs do
		local func = subsInfoFuncs[infoIndex]
		local prefix = MACROTALK_PREFIXES[infoIndex]
		for unitIndex = 1, #subsUnits do
			local localUnit = MACROTALK_LOCALIZED_UNITS[unitIndex]
			local localUnitName = localUnit.name
			local initial = localUnit.initial or localUnitName:sub(1,1)
			local unit = subsUnits[unitIndex]
			text = text:gsub("%%"..prefix..initial,
				UnitExists(unit) and func(unit) or format(MACROTALK_NO_UNIT, localUnitName))
		end
	end
	return OrigSendChatMessage(text, ...)
end




--[[ /group ]]
local function IsInBattleground()
	for i = 1, MAX_BATTLEFIELD_QUEUES do
		status = GetBattlefieldStatus(i)
		if status == "active" then
			return true
		end
	end
	return false
end

SlashCmdList["GROUP_CHAT"] = function(text)
	local channel = 
		IsInBattleground() and "BATTLEGROUND" or
		GetNumRaidMembers() > 0 and "RAID" or
		GetNumPartyMembers() > 0 and "PARTY"
	
	if channel then
		SendChatMessage(text, channel, DEFAULT_CHAT_FRAME.editBox.language)
	else
		DEFAULT_CHAT_FRAME:AddMessage(ERR_NOT_IN_GROUP)
	end
end




--[[ /tellunit ]]
SlashCmdList["TELL_UNIT"] = function(text)
	local unit, message = strsplit(" ", text, 2)
	local name, realm = UnitName(strtrim(unit))
	if realm then
		name = name.."-"..realm
	end
	
	if name then
		SendChatMessage(message, "WHISPER", nil, name)
	end
end




--[[ Option chat commands ]]
do
	local function CreateCmdListEntry(category, command, num)
		if not num then
			num = command
			command = _G[category..1]
		end
		
		for i = 1, num do
			_G["SLASH_OPTION_"..category..i] = OPTION_CHAT_PREFIX..strsub(_G[category..i] or command, 2)
		end
		
		SlashCmdList["OPTION_"..category] = function(message)
			message = SecureCmdOptionParse(message)
			if message then
				local command = command.." "..message
				local origText = ChatFrameEditBox:GetText();
				ChatFrameEditBox:SetText(command);
				ChatEdit_SendText(ChatFrameEditBox);
				ChatFrameEditBox:SetText(origText);
			end
		end
	end

	local baseCommands = {
		SLASH_BATTLEGROUND = 4,
		SLASH_CHANNEL = 4,
		SLASH_EMOTE = 8,
		SLASH_GUILD = 8,
		SLASH_OFFICER = 4,
		SLASH_PARTY = 4,
		SLASH_RAID = 6,
		SLASH_RAID_WARNING = 2,
		SLASH_REPLY = 4,
		SLASH_SAY = 4,
		SLASH_WHISPER = 10,
		SLASH_YELL = 8,
		SLASH_GROUP_CHAT = 2,
		SLASH_TELL_UNIT = 4,
	}
	
	for k, v in pairs(baseCommands) do
		CreateCmdListEntry(k, v)
	end
	
	for i = 1, 10 do
		CreateCmdListEntry("CHANNEL"..i.."_", "/"..i, 1)
	end
end
